<?php

namespace App\Http\Controllers;

use App\Exports\BillingExport;
use App\Imports\BillingImport;
use App\Jobs\ImportFileJob;
use App\Models\Billing;
use App\Models\File;
use Carbon\Carbon;
use Illuminate\Http\Request;
use DataTables;
use Illuminate\Support\Facades\Storage;
use Maatwebsite\Excel\Facades\Excel;
use Illuminate\Support\Facades\Auth;

class BillingController extends Controller
{
    public function datatables($request)
    {
        $records = Billing::orderBy('id', 'desc')->where('received_date', '!=', NULL);
        if (!empty($request->search['value'])) {
            $searchValue = $request->search['value'];
            $records = $records->where(function ($query) use ($searchValue) {
                $query->where('received_date', 'LIKE', "%$searchValue%")
                    ->orWhere('sno', 'LIKE', "%$searchValue%")
                    ->orWhere('hf_id', 'LIKE', "%$searchValue%")
                    ->orWhere('guarantor_account', 'LIKE', "%$searchValue%")
                    ->orWhere('guarantor_name', 'LIKE', "%$searchValue%")
                    ->orWhere('guarantor_address_line1', 'LIKE', "%$searchValue%")
                    ->orWhere('guarantor_address_line2', 'LIKE', "%$searchValue%")
                    ->orWhere('guarantor_address_line3', 'LIKE', "%$searchValue%")
                    ->orWhere('guarantor_city', 'LIKE', "%$searchValue%")
                    ->orWhere('guarantor_state', 'LIKE', "%$searchValue%")
                    ->orWhere('guarantor_zip', 'LIKE', "%$searchValue%")
                    ->orWhere('mrn', 'LIKE', "%$searchValue%")
                    ->orWhere('patient_name', 'LIKE', "%$searchValue%")
                    ->orWhere('date_of_birth', 'LIKE', "%$searchValue%")
                    ->orWhere('department', 'LIKE', "%$searchValue%")
                    ->orWhere('pos', 'LIKE', "%$searchValue%")
                    ->orWhere('pos_type', 'LIKE', "%$searchValue%")
                    ->orWhere('service_provider', 'LIKE', "%$searchValue%")
                    ->orWhere('billing_provider', 'LIKE', "%$searchValue%")
                    ->orWhere('date_of_service', 'LIKE', "%$searchValue%")
                    ->orWhere('diagnosis_codes', 'LIKE', "%$searchValue%")
                    ->orWhere('procedure_code', 'LIKE', "%$searchValue%")
                    ->orWhere('procedure_name', 'LIKE', "%$searchValue%")
                    ->orWhere('rvu', 'LIKE', "%$searchValue%")
                    ->orWhere('charge_amount', 'LIKE', "%$searchValue%")
                    ->orWhere('procedure_qty', 'LIKE', "%$searchValue%")
                    ->orWhere('modifiers', 'LIKE', "%$searchValue%")
                    ->orWhere('payer_name', 'LIKE', "%$searchValue%")
                    ->orWhere('plan_name', 'LIKE', "%$searchValue%")
                    ->orWhere('subscriber_number', 'LIKE', "%$searchValue%")
                    ->orWhere('subscriber_name', 'LIKE', "%$searchValue%")
                    ->orWhere('subscriber_dob', 'LIKE', "%$searchValue%")
                    ->orWhere('subscriber_ssn', 'LIKE', "%$searchValue%")
                    ->orWhere('group_number', 'LIKE', "%$searchValue%")
                    ->orWhere('coverage_address', 'LIKE', "%$searchValue%")
                    ->orWhere('coverage_city', 'LIKE', "%$searchValue%")
                    ->orWhere('coverage_state', 'LIKE', "%$searchValue%")
                    ->orWhere('coverage_zip', 'LIKE', "%$searchValue%")
                    ->orWhere('coverage_phone1', 'LIKE', "%$searchValue%")
                    ->orWhere('coverage_phone2', 'LIKE', "%$searchValue%")
                    ->orWhere('submission_date', 'LIKE', "%$searchValue%")
                    ->orWhere('claim_status', 'LIKE', "%$searchValue%")
                    ->orWhere('primary_received_date', 'LIKE', "%$searchValue%")
                    ->orWhere('primary_amount', 'LIKE', "%$searchValue%")
                    ->orWhere('primary_payment_no', 'LIKE', "%$searchValue%")
                    ->orWhere('primary_ins_payment_date', 'LIKE', "%$searchValue%")
                    ->orWhere('primary_ins_payment_cleared', 'LIKE', "%$searchValue%")
                    ->orWhere('primary_payment_type', 'LIKE', "%$searchValue%")
                    ->orWhere('ar_days', 'LIKE', "%$searchValue%")
                    ->orWhere('secondary_ins_received_date', 'LIKE', "%$searchValue%")
                    ->orWhere('secondary_amount', 'LIKE', "%$searchValue%")
                    ->orWhere('secondary_payment_no', 'LIKE', "%$searchValue%")
                    ->orWhere('secondary_payment_date', 'LIKE', "%$searchValue%")
                    ->orWhere('secondary_payment_cleared', 'LIKE', "%$searchValue%")
                    ->orWhere('secondary_payment_type', 'LIKE', "%$searchValue%")
                    ->orWhere('selfpay_amount', 'LIKE', "%$searchValue%")
                    ->orWhere('selfpay_payment_no', 'LIKE', "%$searchValue%")
                    ->orWhere('selfpay_payment_date', 'LIKE', "%$searchValue%")
                    ->orWhere('selfpay_payment_type', 'LIKE', "%$searchValue%")
                    ->orWhere('claim_comments', 'LIKE', "%$searchValue%")
                    ->orWhere('rendering_provider', 'LIKE', "%$searchValue%")
                    ->orWhere('location_name', 'LIKE', "%$searchValue%")
                    ->orWhere('responsible_payer', 'LIKE', "%$searchValue%")
                    ->orWhere('adjustment', 'LIKE', "%$searchValue%")
                    ->orWhere('patient_responsibility', 'LIKE', "%$searchValue%")
                    ->orWhere('write_off', 'LIKE', "%$searchValue%")
                    ->orWhere('total_payment', 'LIKE', "%$searchValue%")
                    ->orWhere('over_payment', 'LIKE', "%$searchValue%")
                    ->orWhere('insurance_balance', 'LIKE', "%$searchValue%")
                    ->orWhere('patient_balance', 'LIKE', "%$searchValue%")
                    ->orWhere('total_balance', 'LIKE', "%$searchValue%")
                    ->orWhere('ar_aging_by_created_date', 'LIKE', "%$searchValue%")
                    ->orWhere('ar_type', 'LIKE', "%$searchValue%")
                    ->orWhere('primary_claim_id', 'LIKE', "%$searchValue%")
                    ->orWhere('secondary_claim_id', 'LIKE', "%$searchValue%")
                    ->orWhere('status', 'LIKE', "%$searchValue%")
                    ->orWhere('rvu_status', 'LIKE', "%$searchValue%");
            });
        }
        // Custom filters for date-type columns
        $dateColumns = [
            'received_date',
            'created_at',
        ];

        foreach ($dateColumns as $dateColumn) {
            if (!empty($request->$dateColumn)) {
                [$startDate, $endDate] = explode(' - ', $request->$dateColumn);
                $records->whereDate($dateColumn, '>=', Carbon::parse($startDate))
                    ->whereDate($dateColumn, '<=', Carbon::parse($endDate));
            }
        }

        if (!empty($request->claim_status)) {
            $records->where('claim_status', $request->claim_status);
        }

        $totalRecords = $records->count(); // Get the total number of records for pagination
        $data = $records->skip($request->start)
            ->take($request->length)
            ->get();
        return DataTables::of($data)
            ->addIndexColumn()
            ->addColumn('sr_no', function ($row) {
                return '1';
            })
            ->addColumn('sno', function ($row) {
                return '<a target="_blank" href="billings/edit/' . $row->id . '">' . $row->sno . '</a>';
            })
            ->addColumn('received_date', function ($row) {
                return $row->received_date;
            })
            ->addColumn('hf_id', function ($row) {
                return $row->hf_id;
            })
            ->addColumn('guarantor_account', function ($row) {
                return $row->guarantor_account;
            })
            ->addColumn('guarantor_name', function ($row) {
                return $row->guarantor_name;
            })
            ->addColumn('guarantor_address_line_1', function ($row) {
                return $row->guarantor_address_line1;
            })
            ->addColumn('guarantor_address_line_2', function ($row) {
                return $row->guarantor_address_line2;
            })
            ->addColumn('guarantor_address_line_3', function ($row) {
                return $row->guarantor_address_line3;
            })
            ->addColumn('guarantor_city', function ($row) {
                return $row->guarantor_city;
            })
            ->addColumn('guarantor_state', function ($row) {
                return $row->guarantor_state;
            })
            ->addColumn('guarantor_zip', function ($row) {
                return $row->guarantor_zip;
            })
            ->addColumn('mrn', function ($row) {
                return $row->mrn;
            })
            ->addColumn('patient_name', function ($row) {
                return $row->patient_name;
            })
            ->addColumn('date_of_birth', function ($row) {
                return $row->date_of_birth;
            })
            ->addColumn('department', function ($row) {
                return $row->department;
            })
            ->addColumn('pos', function ($row) {
                return $row->pos;
            })
            ->addColumn('pos_type', function ($row) {
                return $row->pos_type;
            })
            ->addColumn('service_provider', function ($row) {
                return $row->service_provider;
            })
            ->addColumn('billing_provider', function ($row) {
                return $row->billing_provider;
            })
            ->addColumn('date_of_service', function ($row) {
                return $row->date_of_service;
            })
            ->addColumn('diagnosis_codes', function ($row) {
                return $row->diagnosis_codes;
            })
            ->addColumn('procedure_code', function ($row) {
                return $row->procedure_code;
            })
            ->addColumn('procedure_name', function ($row) {
                return $row->procedure_name;
            })
            ->addColumn('rvu', function ($row) {
                return $row->rvu;
            })
            ->addColumn('charge_amount', function ($row) {
                return $row->charge_amount;
            })
            ->addColumn('procedure_qty', function ($row) {
                return $row->procedure_qty;
            })
            ->addColumn('modifiers', function ($row) {
                return $row->modifiers;
            })
            ->addColumn('payer_name', function ($row) {
                return $row->payer_name;
            })
            ->addColumn('plan_name', function ($row) {
                return $row->plan_name;
            })
            ->addColumn('subscriber_number', function ($row) {
                return $row->subscriber_number;
            })
            ->addColumn('subscriber_name', function ($row) {
                return $row->subscriber_name;
            })
            ->addColumn('subscriber_dob', function ($row) {
                return $row->subscriber_dob;
            })
            ->addColumn('subscriber_ssn', function ($row) {
                return $row->subscriber_ssn;
            })
            ->addColumn('group_number', function ($row) {
                return $row->group_number;
            })
            ->addColumn('coverage_address', function ($row) {
                return $row->coverage_address;
            })
            ->addColumn('coverage_city', function ($row) {
                return $row->coverage_city;
            })
            ->addColumn('coverage_state', function ($row) {
                return $row->coverage_state;
            })
            ->addColumn('coverage_zip', function ($row) {
                return $row->coverage_zip;
            })
            ->addColumn('coverage_phone_1', function ($row) {
                return $row->coverage_phone1;
            })
            ->addColumn('coverage_phone_2', function ($row) {
                return $row->coverage_phone2;
            })
            ->addColumn('submission_date', function ($row) {
                return $row->submission_date;
            })
            ->addColumn('claim_status', function ($row) {
                $selectedStatus = $row->claim_status; // Assuming $row->status holds the current status of the bill
                return '
                    <select class="form-control bill-field-form claim_status" data-bill-key-name="claim_status" data-bill-id="' . $row->id . '">
                        <option value="no_status" ' . (is_null($selectedStatus) ? 'selected' : '') . '>Claim Status</option>
                        <option value="paid" ' . ($selectedStatus == 'paid' ? 'selected' : '') . '>Paid</option>
                        <option value="rebilled" ' . ($selectedStatus == 'rebilled' ? 'selected' : '') . '>Rebilled</option>
                        <option value="in_process" ' . ($selectedStatus == 'in_process' ? 'selected' : '') . '>In Process</option>
                        <option value="info_required" ' . ($selectedStatus == 'info_required' ? 'selected' : '') . '>Info Required</option>
                        <option value="patient_responsibility" ' . ($selectedStatus == 'patient_responsibility' ? 'selected' : '') . '>Patient Responsibility</option>
                        <option value="partially_paid" ' . ($selectedStatus == 'partially_paid' ? 'selected' : '') . '>Partially Paid</option>
                        <option value="dropped" ' . ($selectedStatus == 'dropped' ? 'selected' : '') . '>Dropped</option>
                        <option value="duplicate" ' . ($selectedStatus == 'duplicate' ? 'selected' : '') . '>Duplicate</option>
                        <option value="denied" ' . ($selectedStatus == 'denied' ? 'selected' : '') . '>Denied</option>
                    </select>
                ';
            })
            ->addColumn('primary_received_date', function ($row) {
                return '<input type="date" data-bill-key-name="primary_received_date" data-bill-id="' . $row->id . '" class="form-control bill-field-form primary_received_date" value="' . $row->primary_received_date . '">';
            })
            ->addColumn('primary_amount', function ($row) {
                return '<input type="number" class="form-control bill-field-form primary_amount" data-bill-key-name="primary_amount" data-bill-id="' . $row->id . '" value="' . $row->primary_amount . '">';
            })
            ->addColumn('primary_payment_no', function ($row) {
                return '<input type="number" class="form-control bill-field-form primary_payment_no" data-bill-key-name="primary_payment_no" data-bill-id="' . $row->id . '" value="' . $row->primary_payment_no . '">';
            })
            ->addColumn('primary_ins_payment_date', function ($row) {
                return '<input type="date" data-bill-key-name="primary_ins_payment_date" data-bill-id="' . $row->id . '" class="form-control bill-field-form primary_ins_payment_date" value="' . $row->primary_ins_payment_date . '">';
            })
            ->addColumn('primary_ins_payment_cleared', function ($row) {
                return $row->primary_ins_payment_cleared;
            })
            ->addColumn('primary_payment_type', function ($row) {
                return $row->primary_payment_type;
            })
            ->addColumn('ar_days', function ($row) {
                return '<input type="number" class="form-control bill-field-form ar_days" data-bill-key-name="ar_days" data-bill-id="' . $row->id . '" value="' . $row->ar_days . '">';
            })
            ->addColumn('secondary_ins_received_date', function ($row) {
                return '<input type="date" data-bill-key-name="secondary_ins_received_date" data-bill-id="' . $row->id . '" class="form-control bill-field-form secondary_ins_received_date" value="' . $row->secondary_ins_received_date . '">';
            })
            ->addColumn('secondary_amount', function ($row) {
                return '<input type="number" class="form-control bill-field-form secondary_amount" data-bill-key-name="secondary_amount" data-bill-id="' . $row->id . '" value="' . $row->secondary_amount . '">';
            })
            ->addColumn('secondary_payment_no', function ($row) {
                return '<input type="number" class="form-control bill-field-form secondary_payment_no" data-bill-key-name="secondary_payment_no" data-bill-id="' . $row->id . '" value="' . $row->secondary_payment_no . '">';
            })
            ->addColumn('secondary_payment_date', function ($row) {
                return '<input type="date" data-bill-key-name="secondary_payment_date" data-bill-id="' . $row->id . '" class="form-control bill-field-form secondary_payment_date" value="' . $row->secondary_payment_date . '">';
            })
            ->addColumn('secondary_payment_cleared', function ($row) {
                return $row->secondary_payment_cleared;
            })
            ->addColumn('secondary_payment_type', function ($row) {
                return $row->secondary_payment_type;
            })
            ->addColumn('selfpay_amount', function ($row) {
                return '<input type="number" class="form-control bill-field-form selfpay_amount" data-bill-key-name="selfpay_amount" data-bill-id="' . $row->id . '" value="' . $row->selfpay_amount . '">';
            })
            ->addColumn('selfpay_payment_no', function ($row) {
                return '<input type="number" class="form-control bill-field-form selfpay_payment_no" data-bill-key-name="selfpay_payment_no" data-bill-id="' . $row->id . '" value="' . $row->selfpay_payment_no . '">';
            })
            ->addColumn('selfpay_payment_date', function ($row) {
                return '<input type="date" data-bill-key-name="selfpay_payment_date" data-bill-id="' . $row->id . '" class="form-control bill-field-form selfpay_payment_date" value="' . $row->selfpay_payment_date . '">';
            })
            ->addColumn('selfpay_payment_type', function ($row) {
                return $row->selfpay_payment_type;
            })
            ->addColumn('claim_comments', function ($row) {
                return '<input type="text" class="form-control bill-field-form claim_comments" data-bill-key-name="claim_comments" data-bill-id="' . $row->id . '" value="' . $row->claim_comments . '">';
            })
            ->addColumn('rendering_provider', function ($row) {
                return $row->rendering_provider;
            })
            ->addColumn('location_name', function ($row) {
                return $row->location_name;
            })
            ->addColumn('responsible_payer', function ($row) {
                return $row->responsible_payer;
            })
            ->addColumn('adjustment', function ($row) {
                return $row->adjustment;
            })
            ->addColumn('patient_responsibility', function ($row) {
                return $row->patient_responsibility;
            })
            ->addColumn('write_off', function ($row) {
                return $row->write_off;
            })
            ->addColumn('total_payment', function ($row) {
                return $row->total_payment;
            })
            ->addColumn('over_payment', function ($row) {
                return $row->over_payment;
            })
            ->addColumn('insurance_balance', function ($row) {
                return $row->insurance_balance;
            })
            ->addColumn('patient_balance', function ($row) {
                return $row->patient_balance;
            })
            ->addColumn('total_balance', function ($row) {
                return $row->total_balance;
            })
            ->addColumn('ar_aging_by_created_date', function ($row) {
                return $row->ar_aging_by_created_date;
            })
            ->addColumn('ar_type', function ($row) {
                return $row->ar_type;
            })
            ->addColumn('primary_claim_id', function ($row) {
                return $row->primary_claim_id;
            })
            ->addColumn('secondary_claim_id', function ($row) {
                return $row->secondary_claim_id;
            })
            ->addColumn('status', function ($row) {
                return $row->status;
            })
            ->addColumn('rvu_status', function ($row) {
                return $row->rvu_status;
            })
            ->addColumn('actions', function ($row) {
                $btns = '
                    <div class="actionb-btns-menu">
                        <a class="btn btns m-0 p-1 p-1" href="billings/edit/' . $row->id . '">
                            <i class="align-middle text-primary" data-feather="edit">
                            </i>
                        </a>
                        <a class="btn btns m-0 p-1 p-1" href="#">
                            <i class="align-middle text-danger" data-feather="trash-2">
                            </i>
                        </a>
                        <a class="btn btns m-0 p-1 p-1" href="#">
                            <i class="align-middle text-success" data-feather="eye">
                            </i>
                        </a>
                    </div>';
                return $btns;
            })
            ->rawColumns(['sr_no', 'sno', 'primary_received_date', 'primary_amount', 'primary_payment_no', 'primary_ins_payment_date', 'primary_ins_payment_cleared', 'primary_payment_type', 'ar_days', 'secondary_ins_received_date', 'secondary_amount', 'secondary_payment_no', 'secondary_payment_date', 'selfpay_amount', 'selfpay_payment_no', 'selfpay_payment_date', 'claim_comments', 'name', 'role', 'claim_status', 'actions'])
            ->setTotalRecords($totalRecords)
            ->setFilteredRecords($totalRecords) // For simplicity, same as totalRecords
            ->skipPaging()
            ->make(true);
    }

    public function getData(Request $request)
    {
        if ($request->ajax()) {
            return $this->datatables($request);
        }
    }
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {
        //
        $data['header_title'] = 'Billings List';
        return view('admin.billings.index', $data);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //
        if ($request->hasFile('file')) {
            $file = $request->file('file');
            $filePath = $file->store('uploads'); // Store the file and get the path

            // Dispatch the job with the file path
            Excel::import(new BillingImport, $filePath);
            // dispatch(new ImportFileJob($filePath));

            // return response()->json(['message' => 'File uploaded and job dispatched successfully', 'path' => $filePath]);
            return redirect('admin/billings')->with('success', 'Data imported successfully');
        }
    }

    public function export(Request $request)
    {
        ini_set('memory_limit', '-1');
        ini_set('max_execution_time', '0');
        $receivedDate = $request->input('received_date');
        $fileName = 'bill_' . time() . '.xlsx';
        $storagePath = 'exports/' . $fileName;

        // Ensure the directory exists
        if (!Storage::exists('exports')) {
            Storage::makeDirectory('exports');
        }

        // Store the file
        Excel::store(new BillingExport($receivedDate), $storagePath, 'public');

        // Return the file download response
        return Excel::download(new BillingExport($receivedDate), $fileName);
    }

    /**
     * Display the specified resource.
     */
    public function show(Billing $billing)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Request $request, $id)
    {
        //
        $data['header_title'] = 'Edit Billing';
        $data['record'] = Billing::find($id);
        if (isset($data['record'])) {
            return view('admin.billings.edit', $data);
        } else {
            return redirect()->back()->with('error', 'No data found');
        }
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        //
        $bill = Billing::find($id);
        if (isset($bill)) {
            $bill->sno = request()->input('sno');
            $bill->user_id = request()->input('user_id');
            $bill->received_date = request()->input('received_date');
            $bill->hf_id = request()->input('hf_id');
            $bill->guarantor_account = request()->input('guarantor_account');
            $bill->guarantor_name = request()->input('guarantor_name');
            $bill->guarantor_address_line1 = request()->input('guarantor_address_line1');
            $bill->guarantor_address_line2 = request()->input('guarantor_address_line2');
            $bill->guarantor_address_line3 = request()->input('guarantor_address_line3');
            $bill->guarantor_city = request()->input('guarantor_city');
            $bill->guarantor_state = request()->input('guarantor_state');
            $bill->guarantor_zip = request()->input('guarantor_zip');
            $bill->mrn = request()->input('mrn');
            $bill->patient_name = request()->input('patient_name');
            $bill->date_of_birth = request()->input('date_of_birth');
            $bill->department = request()->input('department');
            $bill->pos = request()->input('pos');
            $bill->pos_type = request()->input('pos_type');
            $bill->service_provider = request()->input('service_provider');
            $bill->billing_provider = request()->input('billing_provider');
            $bill->date_of_service = request()->input('date_of_service');
            $bill->diagnosis_codes = request()->input('diagnosis_codes');
            $bill->procedure_code = request()->input('procedure_code');
            $bill->procedure_name = request()->input('procedure_name');
            $bill->rvu = request()->input('rvu');
            $bill->charge_amount = request()->input('charge_amount');
            $bill->procedure_qty = request()->input('procedure_qty');
            $bill->modifiers = request()->input('modifiers');
            $bill->payer_name = request()->input('payer_name');
            $bill->plan_name = request()->input('plan_name');
            $bill->subscriber_number = request()->input('subscriber_number');
            $bill->subscriber_name = request()->input('subscriber_name');
            $bill->subscriber_dob = request()->input('subscriber_dob');
            $bill->subscriber_ssn = request()->input('subscriber_ssn');
            $bill->group_number = request()->input('group_number');
            $bill->coverage_address = request()->input('coverage_address');
            $bill->coverage_city = request()->input('coverage_city');
            $bill->coverage_state = request()->input('coverage_state');
            $bill->coverage_zip = request()->input('coverage_zip');
            $bill->coverage_phone1 = request()->input('coverage_phone1');
            $bill->coverage_phone2 = request()->input('coverage_phone2');
            $bill->submission_date = request()->input('submission_date');
            $bill->claim_status = request()->input('claim_status');
            $bill->primary_received_date = request()->input('primary_received_date');
            $bill->primary_amount = request()->input('primary_amount');
            $bill->primary_payment_no = request()->input('primary_payment_no');
            $bill->primary_ins_payment_date = request()->input('primary_ins_payment_date');
            $bill->primary_ins_payment_cleared = request()->input('primary_ins_payment_cleared');
            $bill->primary_payment_type = request()->input('primary_payment_type');
            $bill->ar_days = request()->input('ar_days');
            $bill->secondary_ins_received_date = request()->input('secondary_ins_received_date');
            $bill->secondary_amount = request()->input('secondary_amount');
            $bill->secondary_payment_no = request()->input('secondary_payment_no');
            $bill->secondary_payment_date = request()->input('secondary_payment_date');
            $bill->secondary_payment_cleared = request()->input('secondary_payment_cleared');
            $bill->secondary_payment_type = request()->input('secondary_payment_type');
            $bill->selfpay_amount = request()->input('selfpay_amount');
            $bill->selfpay_payment_no = request()->input('selfpay_payment_no');
            $bill->selfpay_payment_date = request()->input('selfpay_payment_date');
            $bill->selfpay_payment_type = request()->input('selfpay_payment_type');
            $bill->claim_comments = request()->input('claim_comments');
            $bill->rendering_provider = request()->input('rendering_provider');
            $bill->location_name = request()->input('location_name');
            $bill->responsible_payer = request()->input('responsible_payer');
            $bill->adjustment = request()->input('adjustment');
            $bill->patient_responsibility = request()->input('patient_responsibility');
            $bill->write_off = request()->input('write_off');
            $bill->total_payment = request()->input('total_payment');
            $bill->over_payment = request()->input('over_payment');
            $bill->insurance_balance = request()->input('insurance_balance');
            $bill->patient_balance = request()->input('patient_balance');
            $bill->total_balance = request()->input('total_balance');
            $bill->ar_aging_by_created_date = request()->input('ar_aging_by_created_date');
            $bill->ar_type = request()->input('ar_type');
            $bill->primary_claim_id = request()->input('primary_claim_id');
            $bill->secondary_claim_id = request()->input('secondary_claim_id');
            $bill->status = request()->input('status');
            $bill->rvu_status = request()->input('rvu_status');

            $bill->save();
            return redirect()->back()->with('success', 'Bill updated successfully');
        } else {
            return redirect()->back()->with('error', 'No data found');
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Billing $billing)
    {
        //
    }

    public function updateBillField(Request $request)
    {
        try {
            $bill = Billing::find($request->bill_id);
            if (isset($bill)) {
                if ($request->claim_status !== null && $request->claim_status !== '') {
                    $bill->claim_status = ($request->claim_status == 'no_status') ? NULL : $request->claim_status;
                }
                if ($request->primary_received_date !== null && $request->primary_received_date !== '') {
                    $bill->primary_received_date = Carbon::parse($request->primary_received_date)->format('Y-m-d');
                }
                if ($request->primary_amount !== null && $request->primary_amount !== '' && $request->primary_amount >= 0) {
                    $bill->primary_amount = $request->primary_amount;
                }
                if ($request->primary_payment_no !== null && $request->primary_payment_no !== '' && $request->primary_payment_no >= 0) {
                    $bill->primary_payment_no = $request->primary_payment_no;
                }
                if ($request->primary_ins_payment_date !== null && $request->primary_ins_payment_date !== '') {
                    $bill->primary_ins_payment_date = Carbon::parse($request->primary_ins_payment_date)->format('Y-m-d');
                }
                if ($request->primary_ins_payment_date !== null && $request->primary_ins_payment_date !== '') {
                    $bill->primary_ins_payment_date = Carbon::parse($request->primary_ins_payment_date)->format('Y-m-d');
                }
                if ($request->primary_ins_payment_cleared !== null && $request->primary_ins_payment_cleared !== '') {
                    $bill->primary_ins_payment_cleared = Carbon::parse($request->primary_received_date)->format('Y-m-d');
                }
                if ($request->primary_payment_type !== null && $request->primary_payment_type !== '' && $request->primary_payment_type >= 0) {
                    $bill->primary_payment_type = $request->primary_payment_type;
                }
                if ($request->ar_days !== null && $request->ar_days !== '' && $request->ar_days >= 0) {
                    $bill->ar_days = $request->ar_days;
                }
                if ($request->secondary_ins_received_date !== null && $request->secondary_ins_received_date !== '') {
                    $bill->secondary_ins_received_date = Carbon::parse($request->secondary_ins_received_date)->format('Y-m-d');
                }
                if ($request->secondary_amount !== null && $request->secondary_amount !== '' && $request->secondary_amount >= 0) {
                    $bill->secondary_amount = $request->secondary_amount;
                }
                if ($request->secondary_payment_no !== null && $request->secondary_payment_no !== '' && $request->secondary_payment_no >= 0) {
                    $bill->secondary_payment_no = $request->secondary_payment_no;
                }
                if ($request->secondary_payment_date !== null && $request->secondary_payment_date !== '') {
                    $bill->secondary_payment_date = Carbon::parse($request->secondary_payment_date)->format('Y-m-d');
                }
                if ($request->secondary_payment_cleared !== null && $request->secondary_payment_cleared !== '' && $request->secondary_payment_cleared >= 0) {
                    $bill->secondary_payment_cleared = $request->secondary_payment_cleared;
                }
                if ($request->secondary_payment_type !== null && $request->secondary_payment_type !== '' && $request->secondary_payment_type >= 0) {
                    $bill->secondary_payment_type = $request->secondary_payment_type;
                }
                if ($request->selfpay_amount !== null && $request->selfpay_amount !== '' && $request->selfpay_amount >= 0) {
                    $bill->selfpay_amount = $request->selfpay_amount;
                }
                if ($request->selfpay_payment_no !== null && $request->selfpay_payment_no !== '' && $request->selfpay_payment_no >= 0) {
                    $bill->selfpay_payment_no = $request->selfpay_payment_no;
                }
                if ($request->selfpay_payment_date !== null && $request->selfpay_payment_date !== '') {
                    $bill->selfpay_payment_date = Carbon::parse($request->selfpay_payment_date)->format('Y-m-d');
                }
                if ($request->selfpay_payment_type !== null && $request->selfpay_payment_type !== '' && $request->selfpay_payment_type >= 0) {
                    $bill->selfpay_payment_type = $request->selfpay_payment_type;
                }
                if ($request->claim_comments !== null && $request->claim_comments !== '' && $request->claim_comments >= 0) {
                    $bill->claim_comments = $request->claim_comments;
                }
                $bill->save();
                return response()->json(['status' => true, 'message' => 'Updated Successfully']);
            } else {
                return response()->json(['status' => false, 'message' => 'Bill not found']);
            }
        } catch (\Exception $e) {
            return response()->json(['status' => false, 'message' => $e->getMessage()]);
        }
    }
}
