<?php

namespace App\Http\Controllers;

use App\Models\Billing;
use App\Models\User;
use App\Models\UserGroup;
use App\Models\UserHasGroup;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class DashboardController extends Controller
{
    //
    public function index ()
    {
        $data['header_title'] = 'Dashboard';

        $data['groups'] = $this->getAllGroups();
        $data['doctors'] = $this->getAllDoctors();
        $data['locations'] = $this->getAllLocations();
        $data['mrns'] = $this->getAllMRNs();

        $data['noOfEncounters'] = $this->noOfEncounters();
        $data['payments'] = $this->payments();
        $data['inProcessEncounters'] = $this->inProcessEncounters();
        $data['paidRVUs'] = $this->paidRvus();
        $data['pendingRVUs'] = $this->pendingRVUs();
        $data['droppedEncounters'] = $this->droppedEncounters();
        $data['duplicateEncounters'] = $this->duplicateEncounters();
        $data['partiallyPaidEncounters'] = $this->partiallyPaidEncounters();
        $data['deniedEncounters'] = $this->deniedEncounters();

        $userType = Auth::user()->user_type;
        if ($userType == 1) {
            return view('admin.dashboard', $data);
        } else if ($userType == 2) {
            return view('doctor.dashboard', $data);
        } else if ($userType == 3) {
            return view('user.dashboard', $data);
        }
    }
    ///////////////////////////////////////////////////////////////////////
    // Filters start
    ///////////////////////////////////////////////////////////////////////
    public function getAllGroups()
    {
        $records = UserGroup::getAllGroups()->get();
        return $records;
    }

    public function getAllDoctors()
    {
        $records = User::getDoctors()->get();
        return $records;
    }

    public function getAllLocations()
    {
        $records = Billing::getAllLocations();
        return $records;
    }

    public function getAllMRNs()
    {
        $records = Billing::getAllMRNs();
        return $records;
    }
    ///////////////////////////////////////////////////////////////////////
    // Filters end
    ///////////////////////////////////////////////////////////////////////

    
    ///////////////////////////////////////////////////////////////////////
    // Cards start
    ///////////////////////////////////////////////////////////////////////
    public function getUsers()
    {

    }

    public function noOfEncounters()
    {
        $totalEncounters = Billing::getTotalEncounters();
        return $totalEncounters;
    }

    public function payments()
    {
        $totalEncounters = Billing::getAllPayment();
        return $totalEncounters; 
    }

    public function inProcessEncounters()
    {
        $totalEncounters = Billing::inProcessEncounters();
        return $totalEncounters; 
    }

    public function paidRvus()
    {
        $totalEncounters = Billing::paidRvus();
        return $totalEncounters; 
    }

    public function pendingRvus()
    {
        $totalEncounters = Billing::pendingRvus();
        return $totalEncounters; 
    }

    public function droppedEncounters()
    {
        $totalEncounters = Billing::droppedEncounters();
        return $totalEncounters; 
    }

    public function duplicateEncounters()
    {
        $totalEncounters = Billing::duplicateEncounters();
        return $totalEncounters; 
    }

    public function partiallyPaidEncounters()
    {
        $totalEncounters = Billing::partiallyPaidEncounters();
        return $totalEncounters; 
    }

    public function deniedEncounters()
    {
        $totalEncounters = Billing::deniedEncounters();
        return $totalEncounters; 
    }
    ///////////////////////////////////////////////////////////////////////
    // Cards end
    ///////////////////////////////////////////////////////////////////////

    public function fetchAllFilteredData(Request $request)
    {
        $doctors = $this->fetchDoctorsByGroup($request->group_id);
        $locations = $this->fetchLocationsByDoctor($request->group_id, $request->user_id);
        $mrnumbers = $this->fetchMrnNumbersByLocation($request->group_id, $request->user_id, $request->location);
        return response()->json([
            'status' => true,
            'doctors' => $doctors,
            'locations' => $locations,
            'mrn_numbers' => $mrnumbers
        ]);
    }

    public function fetchDoctorsByGroup($groupId)
    {
        $records = User::with('role')->whereHas('role', function ($q) {
            $q->where('name', 'doctor');
        });
        if (!empty($groupId) && $groupId != 'all') {
            $records = $records->whereHas('groups', function ($q) use ($groupId) {
                $q->where('group_id', $groupId);
            });
        }
        $html = "<option value='all' selected>All</option>";
        foreach ($records->get() as $record) {
            $html.= "<option value='". $record->id. "'>". $record->name. "</option>";
        }
        return $html;
    }

    public function fetchLocationsByDoctor($groupId = null, $doctorId = null)
    {
        $subQuery = Billing::select(DB::raw('MIN(id) as id'), 'pos_type')
                    ->where('pos_type', '!=', '')
                    ->groupBy('pos_type');
        if (!empty($groupId) && $groupId != 'all') {
            $groupUserIds = UserHasGroup::where('group_id', $groupId)->pluck('user_id')->toArray();
            $subQuery = $subQuery->whereIn('user_id', $groupUserIds);
        }
        if (!empty($doctorId) && $doctorId != 'all') {
            $subQuery = $subQuery->where('user_id', $doctorId);
        }
        $records = Billing::select('billings.id', 'billings.pos_type')
                    ->joinSub($subQuery, 'min_billings', function ($join) {
                        $join->on('billings.id', '=', 'min_billings.id');
                    });
        $html = "<option value='all' selected>All</option>";
        foreach ($records->get() as $record) {
            $html.= "<option value='". $record->pos_type. "'>". $record->pos_type. "</option>";
        }
        return $html;
    }

    public function fetchMrnNumbersByLocation($groupId = null, $doctorId = null, $location = null)
    {
        $subQuery = Billing::select(DB::raw('MIN(id) as id'), 'mrn')
                    ->where('mrn', '!=', '')
                    ->groupBy('mrn');
        if (!empty($groupId) && $groupId != 'all') {
            $groupUserIds = UserHasGroup::where('group_id', $groupId)->pluck('user_id')->toArray();
            $subQuery = $subQuery->whereIn('user_id', $groupUserIds);
        }
        if (!empty($doctorId) && $doctorId != 'all') {
            $subQuery = $subQuery->where('user_id', $doctorId);
        }
        if (!empty($location) && $location != 'all') {
            if (!empty($doctorId) && $doctorId != 'all') {
                $subQuery = $subQuery->where('user_id', $doctorId);
            }
            $subQuery = $subQuery->where('pos_type', $location);
        }
        $records = Billing::select('billings.id', 'billings.mrn')
                    ->joinSub($subQuery, 'min_billings', function ($join) {
                        $join->on('billings.id', '=', 'min_billings.id');
                    });
        $html = "<option value='all' selected>All</option>";
        foreach ($records->get() as $record) {
            $html.= "<option value='". $record->mrn. "'>". $record->mrn. "</option>";
        }
        return $html;
    }
}
