<?php

namespace App\Http\Controllers;

use App\Models\UserGroup;
use Illuminate\Http\Request;
use DataTables;

class UserGroupController extends Controller
{
    public function datatables($request)
    {
        $records = UserGroup::orderBy('id', 'desc');
        if (!empty($request->search['value'])) {
            $searchValue = $request->search['value'];
            $records = $records->where(function ($query) use ($searchValue) {
                $query->where('name', 'LIKE', "%$searchValue%")
                ->orWhere('address', 'LIKE', "%$searchValue%");
            });
        }
        $totalRecords = $records->count(); // Get the total number of records for pagination
        $data = $records->skip($request->start)
            ->take($request->length)
            ->get();
        return DataTables::of($data)
            ->addIndexColumn()
            ->editColumn('sr_no', function ($row) {
                return '1';
            })
            ->addColumn('name', function ($row) {
                return ucwords($row->name);
            })
            ->addColumn('address', function ($row) {
                return $row->address;
            })
            ->addColumn('phone', function ($row) {
                return $row->phone;
            })
            ->addColumn('actions', function ($row) {
                $btns = '
                    <div class="actionb-btns-menu d-flex justify-content-center">
                        <a class="btn btns m-0 p-1" href="groups/edit/' . $row->id . '">
                            <i class="align-middle text-primary" data-feather="edit">
                            </i>
                        </a>
                        <a class="btn btns m-0 p-1" href="#">
                            <i class="align-middle text-danger" data-feather="trash-2">
                            </i>
                        </a>
                    </div>';
                return $btns;
            })
            ->rawColumns(['sr_no', 'name', 'actions'])
            ->setTotalRecords($totalRecords)
            ->setFilteredRecords($totalRecords) // For simplicity, same as totalRecords
            ->skipPaging()
            ->make(true);
    }
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {
        //
        if ($request->ajax()) {
            return $this->datatables($request);
        }
        $data['header_title'] = 'Groups';
        return view('admin.groups.index', $data);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
        $data['header_title'] = 'Add New Group';
        return view('admin.groups.create', $data);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //
        $this->validate($request, [
            'name' =>'required',
            'address' =>'required',
            'phone' =>'required',
        ]);
        $group = new UserGroup();
        $group->name = $request->name;
        $group->address = $request->address;
        $group->phone = $request->phone;
        $group->save();
        return redirect('admin/groups')->with('success', 'Group added successfully');
    }

    /**
     * Display the specified resource.
     */
    public function show(UserGroup $userGroup)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {
        //
        $data['header_title'] = 'Edit Group';
        $data['record'] = UserGroup::find($id);
        return view('admin.groups.edit', $data);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        //
        $this->validate($request, [
            'name' =>'required',
            'address' =>'required',
            'phone' =>'required',
        ]);
        $group = UserGroup::find($id);
        $group->name = $request->name;
        $group->address = $request->address;
        $group->phone = $request->phone;
        $group->save();
        return redirect('admin/groups')->with('success', 'Group updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(UserGroup $userGroup)
    {
        //
    }
}
