<?php

namespace App\Imports;

use App\Events\JobCompleted;
use App\Models\Billing;
use Carbon\Carbon;
use Maatwebsite\Excel\Concerns\Importable;
use Maatwebsite\Excel\Concerns\WithEvents;
use Maatwebsite\Excel\Concerns\ToModel;
use Maatwebsite\Excel\Concerns\WithHeadingRow;
use Maatwebsite\Excel\Events\AfterImport;

class BillingImport implements ToModel, WithHeadingRow, WithEvents
{
    use Importable;


    /**
    * @param array $row
    *
    * @return \Illuminate\Database\Eloquent\Model|null
    */
    public function model(array $row)
    {
        $attributes = $row;
        // Validate and format specific date columns
        $attributes['received_date'] = $this->validateDate(!empty($row['received_date']) ? $row['received_date'] : now());
        $attributes['date_of_birth'] = $this->validateDate(!empty($row['date_of_birth']) ? $row['date_of_birth'] : now());
        $attributes['date_of_service'] = $this->validateDate(!empty($row['date_of_service']) ? $row['date_of_service'] : now());
        $attributes['submission_date'] = $this->validateDate(!empty($row['submission_date']) ? $row['submission_date'] : now());
        $attributes['primary_received_date'] = $this->validateDate(!empty($row['primary_received_date']) ? $row['primary_received_date'] : now());
        $attributes['pri_ins_payment_date'] = $this->validateDate(!empty($row['pri_ins_payment_date']) ? $row['pri_ins_payment_date'] : now());
        $attributes['sec_ins_received_date'] = $this->validateDate(!empty($row['sec_ins_received_date']) ? $row['sec_ins_received_date'] : now());
        $attributes['sec_payment_date'] = $this->validateDate(!empty($row['sec_payment_date']) ? $row['sec_payment_date'] : now());
        $attributes['selfpay_payment_date'] = $this->validateDate(!empty($row['selfpay_payment_date']) ? $row['selfpay_payment_date'] : now());
        $attributes['subscriber_dob'] = $this->validateDate(!empty($row['subscriber_dob']) ? $row['subscriber_dob'] : now());

        if (!empty($row['claim_status'])) {
            if ($row['claim_status'] == 'PAID') {
                $attributes['claim_status'] = 'paid';
            } else if ($row['claim_status'] == 'Rebilled') {
                $attributes['claim_status'] = 'rebilled';
            } else if ($row['claim_status'] == 'In Process') {
                $attributes['claim_status'] = 'in_process';
            } else if ($row['claim_status'] == 'Info Required') {
                $attributes['claim_status'] = 'info_required';
            } else if ($row['claim_status'] == 'Patient Responsibility') {
                $attributes['claim_status'] = 'patient_responsibility';
            } else if ($row['claim_status'] == 'Paritially Paid') {
                $attributes['claim_status'] = 'partially_paid';
            } else if ($row['claim_status'] == 'Droped') {
                $attributes['claim_status'] = 'dropped';
            } else if ($row['claim_status'] == 'Duplicate') {
                $attributes['claim_status'] = 'duplicate';
            } else if ($row['claim_status'] == 'Denied') {
                $attributes['claim_status'] = 'denied';

            } else if ($row['claim_status'] == 'In Process secondary') {
                $attributes['claim_status'] = 'in_process_secondary';
            } else if ($row['claim_status'] == 'rebilled secondary') {
                $attributes['claim_status'] = 'rebilled_secondary';
            } else if ($row['claim_status'] == 'info required secondary') {
                $attributes['claim_status'] = 'info_required_secondary';
            } else if ($row['claim_status'] == 'In Process primary') {
                $attributes['claim_status'] = 'in_process_primary';
            } else if ($row['claim_status'] == 'rebilled primary') {
                $attributes['claim_status'] = 'rebilled_primary';
            } else if ($row['claim_status'] == 'info required primary') {
                $attributes['claim_status'] = 'info_required_primary';
            }
        }

        if (!empty($row['id'])) {
            $billing = Billing::find($row['id']);
            if (isset($billing)) {
                $billing->update($attributes);
            } else {
                $billing = new Billing($attributes);
                $billing->save();
            }
        } else {
            $billing = new Billing($attributes);
            $billing->save();
        }
    
        return $billing;
    }
    private function validateDate($date)
    {
        // Attempt to parse the date
        try {
            return Carbon::parse($date)->format('Y-m-d');
            
            // $getDate = \Carbon\Carbon::createFromFormat('m/d/Y', $date);
            // $formattedDate = $getDate->format('Y-m-d');
            // return $formattedDate; // Format date to YYYY-MM-DD
        } catch (\Exception $e) {
            return null; // or handle as required
        }
    }


    public static function afterImport(AfterImport $event)
    {
        // Dispatch the JobCompleted event after the import is completed
        // event(new JobCompleted('File imported successfully'));
    }

    public function registerEvents(): array
    {
        return [
            AfterImport::class => [self::class, 'afterImport'],
        ];
    }
}
