<?php

namespace App\Jobs;

use App\Models\Billing;
use App\Models\User;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Hash;
use Spatie\Permission\Models\Role;
use Illuminate\Support\Str;

class SyncUsersJob implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    /**
     * Create a new job instance.
     */
    public function __construct()
    {
        //
    }

    /**
     * Execute the job.
     */
    public function handle()
    {
        $role = Role::where('name', 'doctor')->first(); // Fetch the role once

        // Fetch all distinct users at once
        $distinctUsers = Billing::select('guarantor_name')
            ->distinct()
            ->get();

        // Prepare users for bulk insert
        $newUsers = [];
        $userNames = [];

        foreach ($distinctUsers as $user) {
            if (!empty($user->guarantor_name)) {
                $userName = $user->guarantor_name;
                $newEmail = $this->generateNewEmail($userName);

                if (!in_array($newEmail, $userNames) && !User::where('email', $newEmail)->exists()) {
                    $newUsers[] = [
                        'name' => $userName,
                        'email' => $newEmail,
                        'password' => Hash::make('12345678'), // Ensure the password is hashed
                        'user_type' => isset($role) ? $role->id : '',
                        'created_at' => now(),
                        'updated_at' => now()
                    ];
                    $userNames[] = $newEmail;
                }
            }
        }

        // Bulk insert new users
        if (!empty($newUsers)) {
            User::insert($newUsers);

            // Fetch newly inserted users by email
            $newUserEmails = array_column($newUsers, 'email');
            $insertedUsers = User::whereIn('email', $newUserEmails)->get();

            foreach ($insertedUsers as $user) {
                // Assign role
                $user->assignRole($role);

                // Prepare billing updates
                $bills = Billing::where('guarantor_name', $user->name)->get();
                foreach ($bills as $bill) {
                    $bill->update(['user_id' => $user->id]);
                }
            }
            $billData = Billing::orderBy('id', 'desc')->take(1)->first();
            $billData->user_sync_status = 1;
            $billData->user_sync_notification = 1;
            $billData->save();
        }
    }

    function generateNewEmail($userName)
    {
        $userName = trim(str_replace(',', '_', $userName));
        return strtolower(str_replace(' ', '_', $userName)) . "@thebillsnap.com";
    }
}
