<?php

namespace App\Models;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Support\Facades\DB;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx\Rels;
use Request;

class Billing extends Model
{
    use HasFactory, SoftDeletes;

    protected $guarded = ['id'];

    static public function getTotalEncounters()
    {
        $groupId = Request::get('group_id');
        $doctorId = Request::get('doctor_id');
        $location = Request::get('location');
        $startDate = Request::get('start_date');
        $endDate = Request::get('end_date');
        $mrnNumber = Request::get('mrn_number');

        $mainQuery = Billing::query();

        if (!empty($groupId) && $groupId != 'all') {
            $groupUserIds = UserHasGroup::where('group_id', $groupId)->pluck('user_id')->toArray();
            $mainQuery = $mainQuery->whereIn('user_id', $groupUserIds);
        }
        if (!empty($doctorId) && $doctorId != 'all') {
            $mainQuery = $mainQuery->where('user_id', $doctorId);
        }
        if (!empty($location) && $location != 'all') {
            $mainQuery = $mainQuery->where('pos_type', $location);
        }
        if (!empty($startDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '>=', $startDate);
        }
        if (!empty($endDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '<=', $endDate);
        }
        if (!empty($mrnNumber) && $mrnNumber != 'all') {
            $mainQuery = $mainQuery->where('mrn', $mrnNumber);
        }
        $records = $mainQuery->count();
        return $records;
    }

    static public function getAllPayment()
    {
        $groupId = Request::get('group_id');
        $doctorId = Request::get('doctor_id');
        $location = Request::get('location');
        $startDate = Request::get('start_date');
        $endDate = Request::get('end_date');
        $mrnNumber = Request::get('mrn_number');

        $mainQuery = Billing::query();

        if (!empty($groupId) && $groupId != 'all') {
            $groupUserIds = UserHasGroup::where('group_id', $groupId)->pluck('user_id')->toArray();
            $mainQuery = $mainQuery->whereIn('user_id', $groupUserIds);
        }
        if (!empty($doctorId) && $doctorId != 'all') {
            $mainQuery = $mainQuery->where('user_id', $doctorId);
        }
        if (!empty($location) && $location != 'all') {
            $mainQuery = $mainQuery->where('pos_type', $location);
        }
        if (!empty($startDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '>=', $startDate);
        }
        if (!empty($endDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '<=', $endDate);
        }
        if (!empty($mrnNumber) && $mrnNumber != 'all') {
            $mainQuery = $mainQuery->where('mrn', $mrnNumber);
        }
        
        $allPayments = $mainQuery->sum(DB::raw('COALESCE(primary_amount, 0) + COALESCE(secondary_amount, 0) + COALESCE(selfpay_amount, 0)'));

        return $allPayments;
    }

    static public function inProcessEncounters()
    {
        $groupId = Request::get('group_id');
        $doctorId = Request::get('doctor_id');
        $location = Request::get('location');
        $startDate = Request::get('start_date');
        $endDate = Request::get('end_date');
        $mrnNumber = Request::get('mrn_number');

        $mainQuery = Billing::where(function ($q) {
            $q->where('claim_status', 'in_process')->orWhere('claim_status', 'rebilled');
        });

        if (!empty($groupId) && $groupId != 'all') {
            $groupUserIds = UserHasGroup::where('group_id', $groupId)->pluck('user_id')->toArray();
            $mainQuery = $mainQuery->whereIn('user_id', $groupUserIds);
        }
        if (!empty($doctorId) && $doctorId != 'all') {
            $mainQuery = $mainQuery->where('user_id', $doctorId);
        }
        if (!empty($location) && $location != 'all') {
            $mainQuery = $mainQuery->where('pos_type', $location);
        }
        if (!empty($startDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '>=', $startDate);
        }
        if (!empty($endDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '<=', $endDate);
        }
        if (!empty($mrnNumber) && $mrnNumber != 'all') {
            $mainQuery = $mainQuery->where('mrn', $mrnNumber);
        }
        
        $records = $mainQuery->count();

        return $records;
    }

    static public function paidRvus()
    {
        $groupId = Request::get('group_id');
        $doctorId = Request::get('doctor_id');
        $location = Request::get('location');
        $startDate = Request::get('start_date');
        $endDate = Request::get('end_date');
        $mrnNumber = Request::get('mrn_number');

        $mainQuery = Billing::where('claim_status', 'paid');

        if (!empty($groupId) && $groupId != 'all') {
            $groupUserIds = UserHasGroup::where('group_id', $groupId)->pluck('user_id')->toArray();
            $mainQuery = $mainQuery->whereIn('user_id', $groupUserIds);
        }
        if (!empty($doctorId) && $doctorId != 'all') {
            $mainQuery = $mainQuery->where('user_id', $doctorId);
        }
        if (!empty($location) && $location != 'all') {
            $mainQuery = $mainQuery->where('pos_type', $location);
        }
        if (!empty($startDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '>=', $startDate);
        }
        if (!empty($endDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '<=', $endDate);
        }
        if (!empty($mrnNumber) && $mrnNumber != 'all') {
            $mainQuery = $mainQuery->where('mrn', $mrnNumber);
        }
        $records = $mainQuery->sum('rvu');
        
        return $records;
    }

    static public function pendingRvus()
    {
        $groupId = Request::get('group_id');
        $doctorId = Request::get('doctor_id');
        $location = Request::get('location');
        $startDate = Request::get('start_date');
        $endDate = Request::get('end_date');
        $mrnNumber = Request::get('mrn_number');

        $mainQuery = Billing::where('claim_status', '!=', 'paid')->where('claim_status', '!=', 'dropped')->where('claim_status', '!=', 'duplicate');

        if (!empty($groupId) && $groupId != 'all') {
            $groupUserIds = UserHasGroup::where('group_id', $groupId)->pluck('user_id')->toArray();
            $mainQuery = $mainQuery->whereIn('user_id', $groupUserIds);
        }
        if (!empty($doctorId) && $doctorId != 'all') {
            $mainQuery = $mainQuery->where('user_id', $doctorId);
        }
        if (!empty($location) && $location != 'all') {
            $mainQuery = $mainQuery->where('pos_type', $location);
        }
        if (!empty($startDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '>=', $startDate);
        }
        if (!empty($endDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '<=', $endDate);
        }
        if (!empty($mrnNumber) && $mrnNumber != 'all') {
            $mainQuery = $mainQuery->where('mrn', $mrnNumber);
        }
        $records = $mainQuery->sum('rvu');
        return $records;
    }

    static public function droppedEncounters()
    {
        $groupId = Request::get('group_id');
        $doctorId = Request::get('doctor_id');
        $location = Request::get('location');
        $startDate = Request::get('start_date');
        $endDate = Request::get('end_date');
        $mrnNumber = Request::get('mrn_number');

        $mainQuery = Billing::where('claim_status', '=', 'dropped');

        if (!empty($groupId) && $groupId != 'all') {
            $groupUserIds = UserHasGroup::where('group_id', $groupId)->pluck('user_id')->toArray();
            $mainQuery = $mainQuery->whereIn('user_id', $groupUserIds);
        }
        if (!empty($doctorId) && $doctorId != 'all') {
            $mainQuery = $mainQuery->where('user_id', $doctorId);
        }
        if (!empty($location) && $location != 'all') {
            $mainQuery = $mainQuery->where('pos_type', $location);
        }
        if (!empty($startDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '>=', $startDate);
        }
        if (!empty($endDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '<=', $endDate);
        }
        if (!empty($mrnNumber) && $mrnNumber != 'all') {
            $mainQuery = $mainQuery->where('mrn', $mrnNumber);
        }
        $records = $mainQuery->count();
        return $records;
    }

    static public function duplicateEncounters()
    {
        $groupId = Request::get('group_id');
        $doctorId = Request::get('doctor_id');
        $location = Request::get('location');
        $startDate = Request::get('start_date');
        $endDate = Request::get('end_date');
        $mrnNumber = Request::get('mrn_number');

        $mainQuery = Billing::where('claim_status', '=', 'duplicate');

        if (!empty($groupId) && $groupId != 'all') {
            $groupUserIds = UserHasGroup::where('group_id', $groupId)->pluck('user_id')->toArray();
            $mainQuery = $mainQuery->whereIn('user_id', $groupUserIds);
        }
        if (!empty($doctorId) && $doctorId != 'all') {
            $mainQuery = $mainQuery->where('user_id', $doctorId);
        }
        if (!empty($location) && $location != 'all') {
            $mainQuery = $mainQuery->where('pos_type', $location);
        }
        if (!empty($startDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '>=', $startDate);
        }
        if (!empty($endDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '<=', $endDate);
        }
        if (!empty($mrnNumber) && $mrnNumber != 'all') {
            $mainQuery = $mainQuery->where('mrn', $mrnNumber);
        }
        $records = $mainQuery->count();
        return $records;
    }

    static public function partiallyPaidEncounters()
    {        
        $groupId = Request::get('group_id');
        $doctorId = Request::get('doctor_id');
        $location = Request::get('location');
        $startDate = Request::get('start_date');
        $endDate = Request::get('end_date');
        $mrnNumber = Request::get('mrn_number');

        $mainQuery = Billing::where('claim_status', '=', 'partially_paid');

        if (!empty($groupId) && $groupId != 'all') {
            $groupUserIds = UserHasGroup::where('group_id', $groupId)->pluck('user_id')->toArray();
            $mainQuery = $mainQuery->whereIn('user_id', $groupUserIds);
        }
        if (!empty($doctorId) && $doctorId != 'all') {
            $mainQuery = $mainQuery->where('user_id', $doctorId);
        }
        if (!empty($location) && $location != 'all') {
            $mainQuery = $mainQuery->where('pos_type', $location);
        }
        if (!empty($startDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '>=', $startDate);
        }
        if (!empty($endDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '<=', $endDate);
        }
        if (!empty($mrnNumber) && $mrnNumber != 'all') {
            $mainQuery = $mainQuery->where('mrn', $mrnNumber);
        }
        $records = $mainQuery->count();
        return $records;
    }

    static public function deniedEncounters()
    {      
        $groupId = Request::get('group_id');
        $doctorId = Request::get('doctor_id');
        $location = Request::get('location');
        $startDate = Request::get('start_date');
        $endDate = Request::get('end_date');
        $mrnNumber = Request::get('mrn_number');

        $mainQuery = Billing::where('claim_status', '=', 'denied');  

        if (!empty($groupId) && $groupId != 'all') {
            $groupUserIds = UserHasGroup::where('group_id', $groupId)->pluck('user_id')->toArray();
            $mainQuery = $mainQuery->whereIn('user_id', $groupUserIds);
        }
        if (!empty($doctorId) && $doctorId != 'all') {
            $mainQuery = $mainQuery->where('user_id', $doctorId);
        }
        if (!empty($location) && $location != 'all') {
            $mainQuery = $mainQuery->where('pos_type', $location);
        }
        if (!empty($startDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '>=', $startDate);
        }
        if (!empty($endDate)) {
            $mainQuery = $mainQuery->whereDate('created_at', '<=', $endDate);
        }
        if (!empty($mrnNumber) && $mrnNumber != 'all') {
            $mainQuery = $mainQuery->where('mrn', $mrnNumber);
        }
        $records = $mainQuery->count();
        return $records;
    }

    //

    static public function getAllGroups()
    {
        $groupId = Request::get('group_id');
        $records = self::with('user.group')->whereHas('user', function ($q) {
            $q->where('group_id', Request::get('group_id'));
        })->orderBy('id', 'desc');
        if (!empty($groupId)) {
            $records = $records->whereDate('group_id', '>=', $groupId);
        }
        return $records->get();
    }

    static public function getAllLocations()
    {
        $mainQuery = Billing::select(DB::raw('MIN(id) as id'), 'pos_type')
        ->where('pos_type', '!=', '')
        ->groupBy('pos_type');
        if (!empty(Request::get('group_id')) && Request::get('group_id') != 'all') {
            $groupUserIds = UserHasGroup::where('group_id', Request::get('group_id'))->pluck('user_id')->toArray();
            $mainQuery = $mainQuery->whereIn('user_id', $groupUserIds);
        }
        if (!empty(Request::get('doctor_id')) && Request::get('doctor_id') != 'all') {
            $mainQuery = $mainQuery->where('user_id', Request::get('doctor_id'));
        }
        $records = Billing::select('billings.id', 'billings.pos_type')
                    ->joinSub($mainQuery, 'min_billings', function ($join) {
                        $join->on('billings.id', '=', 'min_billings.id');
                    });

        return $records->get();
    }

    static public function getAllMRNs()
    {
        $mainQuery = Billing::select(DB::raw('MIN(id) as id'), 'mrn')
                    ->where('mrn', '!=', '')
                    ->groupBy('mrn');
        if (!empty(Request::get('group_id')) && Request::get('group_id') != 'all') {
            $groupUserIds = UserHasGroup::where('group_id', Request::get('group_id'))->pluck('user_id')->toArray();
            $mainQuery = $mainQuery->whereIn('user_id', $groupUserIds);
        }
        if (!empty(Request::get('doctor_id')) && Request::get('doctor_id') != 'all') {
            $mainQuery = $mainQuery->where('user_id', Request::get('doctor_id'));
        }
        if (!empty(Request::get('location')) && Request::get('location') != 'all') {
            if (!empty(Request::get('doctor_id')) && Request::get('doctor_id') != 'all') {
                $mainQuery = $mainQuery->where('user_id', Request::get('doctor_id'));
            }
            $mainQuery = $mainQuery->where('pos_type', Request::get('location'));
        }
        $records = Billing::select('billings.id', 'billings.mrn')
                ->joinSub($mainQuery, 'min_billings', function ($join) {
                    $join->on('billings.id', '=', 'min_billings.id');
                });
    
        return $records->get();
    }

    // Relations 

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id', 'id');
    }
    
    public function user_group()
    {
        return $this->hasMany(UserHasGroup::class, 'user_id', 'user_id');
    }
}
