<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;
use Spatie\Permission\Models\Role;
use Spatie\Permission\Traits\HasRoles;
use Request;

class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable, HasRoles, SoftDeletes;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'name',
        'email',
        'password',
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'password' => 'hashed',
    ];

    static public function getDoctors()
    {
        $records = User::with('role')->whereHas('role', function ($q) {
            $q->where('name', 'doctor');
        });
        if (!empty(Request::get('group_id')) && Request::get('group_id') != 'all') {
            $records = $records->whereHas('groups', function ($q) {
                $q->where('group_id', Request::get('group_id'));
            });
        }
        return $records;
    }

    // Relations

    public function role()
    {
        return $this->belongsTo(Role::class, 'user_type', 'id');
    }

    public function groups()
    {
        return $this->hasMany(UserHasGroup::class, 'user_id', 'id');
    }
}
