@extends('layout.app')
@section('_styles')
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
<style type="text/css">
    .select2-container .select2-selection--single {
        display: block;
        width: 100%;
        height: calc(2.25rem + 2px);
        padding: .375rem .25rem;
        font-size: 1rem;
        font-weight: 400;
        line-height: 1.5;
        color: #495057;
        background-color: #fff;
        background-clip: padding-box;
        border: 1px solid #ced4da;
        border-radius: .25rem;
        box-shadow: inset 0 0 0 transparent;
        transition: border-color .15s ease-in-out, box-shadow .15s ease-in-out;
    }
</style>
@endsection
@section('content')

<div class="container-fluid flex-grow-1 container-p-y">
    @include('_messages')
    <div class="row">
        <div class="col-12 d-flex justify-content-between">
            <div class="breadcrumb-list">
                <h4 class="fw-bold py-3 mb-4">Dashboard</h4>
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-lg-12 mb-4">
            <div class="card p-4">
                <form action="">
                    <div class="row mb-3">
                        <div class="col-lg-4 col-md-4">
                            <label for="">Select Group</label>
                            <select name="group_id" id="group_id" value="{{Request::get('group_id')}}" class="form-control">
                                <option value="all" selected>All</option>
                                @if (!empty($groups))
                                    @foreach ($groups as $group)
                                    <option value="{{$group->id}}" {{(!empty(Request::get('group_id')) && Request::get('group_id') == $group->id) ? 'selected' : ''}}>{{$group->name}}</option>
                                    @endforeach
                                @endif
                            </select>
                        </div>
                        <div class="col-lg-4 col-md-4">
                            <label for="">Select Doctor</label>
                            <select name="doctor_id" id="doctor_id" value="{{Request::get('doctor_id')}}" class="form-control">
                                <option value="all" selected>All</option>
                                @if (!empty($doctors))
                                    @foreach ($doctors as $doctor)
                                        <option value="{{$doctor->id}}" {{(!empty(Request::get('doctor_id')) && Request::get('doctor_id') == $doctor->id) ? 'selected' : ''}}>{{$doctor->name}}</option>
                                    @endforeach
                                @endif
                            </select>
                        </div>
                        <div class="col-lg-4 col-md-4">
                            <label for="">Select Location</label>
                            <select name="location" id="location" value="{{Request::get('location')}}" class="form-control">
                                <option value="all" selected>All</option>
                                @if (!empty($locations))
                                    @foreach ($locations as $location)
                                        <option value="{{$location->pos_type}}" {{(!empty(Request::get('location')) && Request::get('location') == $location->pos_type) ? 'selected' : ''}}>{{$location->pos_type}}</option>
                                    @endforeach
                                @endif
                            </select>
                        </div>
                    </div>
                    <div class="row mb-3">
                        <div class="col-lg-4 col-md-4">
                            <label for="">Start Date</label>
                            <input type="date" name="start_date" value="{{Request::get('start_date')}}" class="form-control">
                        </div>
                        <div class="col-lg-4 col-md-4">
                            <label for="">End Date</label>
                            <input type="date" name="end_date" value="{{Request::get('end_date')}}" class="form-control">
                        </div>
                        <div class="col-lg-4 col-md-4">
                            <label for="">Select MRN</label>
                            <select name="mrn_number" id="mrn_number" value="{{Request::get('mrn_number')}}" class="form-control">
                                <option value="" selected>All</option>
                                @if (!empty($mrns))
                                    @foreach ($mrns as $mrn)
                                    <option value="{{$mrn->mrn}}" {{(!empty(Request::get('mrn_number')) && Request::get('mrn_number') == $mrn->mrn) ? 'selected' : ''}}>{{$mrn->mrn}}</option>
                                    @endforeach
                                @endif
                            </select>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-3">
                            <button type="submit" class="btn btn-primary">Apply</button>
                            <a href="{{url('admin/dashboard')}}" type="submit" class="btn btn-danger">Clear All</a>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-lg-12 col-md-12 order-1">
            <div class="row">
                <div class="col-3 mb-4">
                    <div class="card">
                        <div class="card-body">
                            <span class="d-block mb-1"><i class="menu-icon tf-icons bx bx-group"></i> No. of Users</span>
                            <h3 class="card-title text-nowrap mb-2">{{!empty($doctors) ? number_format($doctors->count()) : 0}}</h3>
                        </div>
                    </div>
                </div>
                <div class="col-3 mb-4">
                    <div class="card">
                        <div class="card-body">
                            <span class="d-block mb-1"><i class="menu-icon tf-icons bx bx-file"></i> No. of Encounters</span>
                            <h3 class="card-title text-nowrap mb-2">{{!empty($noOfEncounters) ? number_format($noOfEncounters) : 0}}</h3>
                        </div>
                    </div>
                </div>
                <div class="col-3 mb-4">
                    <div class="card">
                        <div class="card-body">
                            <span class="d-block mb-1"><i class="menu-icon tf-icons bx bx-money"></i> Payments</span>
                            <h3 class="card-title text-nowrap mb-2">${{!empty($payments) ? number_format($payments, 2) : 0}}</h3>
                        </div>
                    </div>
                </div>
                <div class="col-3 mb-4">
                    <div class="card">
                        <div class="card-body">
                            <span class="d-block mb-1"><i class="menu-icon tf-icons bx bx-file"></i> In-Process Encounters</span>
                            <h3 class="card-title text-nowrap mb-2">{{!empty($inProcessEncounters) ? $inProcessEncounters : 0}}</h3>
                        </div>
                    </div>
                </div>
            </div>
            <div class="row">
                <div class="col-3 mb-4">
                    <div class="card">
                        <div class="card-body">
                            <span class="d-block mb-1"><i class="menu-icon tf-icons bx bx-file"></i> Paid RVUs</span>
                            <h3 class="card-title text-nowrap mb-2">{{!empty($paidRVUs) ? $paidRVUs : 0}}</h3>
                        </div>
                    </div>
                </div>
                <div class="col-3 mb-4">
                    <div class="card">
                        <div class="card-body">
                            <span class="d-block mb-1"><i class="menu-icon tf-icons bx bx-file"></i> Pending RVUs</span>
                            <h3 class="card-title text-nowrap mb-2">{{!empty($pendingRVUs) ? $pendingRVUs : 0}}</h3>
                        </div>
                    </div>
                </div>
                <div class="col-3 mb-4">
                    <div class="card">
                        <div class="card-body">
                            <span class="d-block mb-1"><i class="menu-icon tf-icons bx bx-file"></i> Dropped Encounters</span>
                            <h3 class="card-title text-nowrap mb-2">{{!empty($droppedEncounters) ? $droppedEncounters : 0}}</h3>
                        </div>
                    </div>
                </div>
                <div class="col-3 mb-4">
                    <div class="card">
                        <div class="card-body">
                            <span class="d-block mb-1"><i class="menu-icon tf-icons bx bx-file"></i> Duplicate Encounters</span>
                            <h3 class="card-title text-nowrap mb-2">{{!empty($duplicateEncounters) ? $duplicateEncounters : 0}}</h3>
                        </div>
                    </div>
                </div>
            </div>
            <div class="row">
                <div class="col-3 mb-4">
                    <div class="card">
                        <div class="card-body">
                            <span class="d-block mb-1"><i class="menu-icon tf-icons bx bx-file"></i> Paritally Paid Encounters</span>
                            <h3 class="card-title text-nowrap mb-2">{{!empty($partiallyPaidEncounters) ? $partiallyPaidEncounters : 0}}</h3>
                        </div>
                    </div>
                </div>
                <div class="col-3 mb-4">
                    <div class="card">
                        <div class="card-body">
                            <span class="d-block mb-1"><i class="menu-icon tf-icons bx bx-file"></i> Denied Encounters</span>
                            <h3 class="card-title text-nowrap mb-2">{{!empty($deniedEncounters) ? $deniedEncounters : 0}}</h3>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

@endsection

@section('_scripts')
<script>
    $(document).ready(function() {
        $('select').select2();

        function callAjax() {
        }

        $(document).on('change', '#group_id', function() {
            var url = "{{route('filter_all_data')}}";
            $.ajax({
                url: url,
                type: 'POST',
                data: {
                    _token: "{{csrf_token()}}",
                    group_id: $('#group_id').val(),
                    user_id: '',
                    location: '',
                },
                success: function(response) {
                    if (response.status == true) {
                        $('#doctor_id').html(response.doctors);
                        $('#location').html(response.locations);
                        $('#mrn_number').html(response.mrn_numbers);
                    }
                }
            });
        });

        $(document).on('change', '#doctor_id', function() {
            var url = "{{route('filter_all_data')}}";
            $.ajax({
                url: url,
                type: 'POST',
                data: {
                    _token: "{{csrf_token()}}",
                    group_id: '',
                    user_id: $('#doctor_id').val(),
                    location: '',
                },
                success: function(response) {
                    if (response.status == true) {
                        $('#location').html(response.locations);
                        $('#mrn_number').html(response.mrn_numbers);
                    }
                }
            });
        });

        $(document).on('change', '#location', function() {
            var url = "{{route('filter_all_data')}}";
            $.ajax({
                url: url,
                type: 'POST',
                data: {
                    _token: "{{csrf_token()}}",
                    group_id: '',
                    user_id: $('#doctor_id').val(),
                    location: $('#location').val(),
                },
                success: function(response) {
                    if (response.status == true) {
                        $('#mrn_number').html(response.mrn_numbers);
                    }
                }
            });
        });

    });
</script>
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
@endsection