<?php

use App\Http\Controllers\AclController;
use App\Http\Controllers\AuthController;
use App\Http\Controllers\BillingController;
use App\Http\Controllers\DashboardController;
use App\Http\Controllers\FileController;
use App\Http\Controllers\NotificationController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\UserGroupController;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/


Auth::routes();

Route::get('/', [AuthController::class, 'login']);
Route::get('/login', [AuthController::class, 'login'])->name('login');
Route::post('/login', [AuthController::class, 'postLogin'])->name('post_login');
Route::get('/register', [AuthController::class, 'register'])->name('register');
Route::post('/register', [AuthController::class, 'postRegister'])->name('post_register');
Route::get('/logout', [AuthController::class, 'logout'])->name('postlogout');

Route::post('/send-notification', [NotificationController::class, 'sendNotification'])->name('send_notification');
Route::post('/get-notifications', [NotificationController::class, 'getNotifications'])->name('get_notifications');

Route::group(['prefix' => '', 'middleware' => 'auth'], function () {
        
    //Admin Routes
    Route::group(['prefix' => 'admin'], function () {

        //Dashboard Routes
        Route::get('/dashboard', [DashboardController::class, 'index'])->name('admin.dashboard');
        Route::post('/get-filtered-data', [DashboardController::class, 'index'])->name('admin.get_filtered_data');

        Route::post('/filter-all-data', [DashboardController::class, 'fetchAllFilteredData'])->name('filter_all_data');

        Route::post('/fetch-doctors-by-group', [DashboardController::class, 'fetchDoctorsByGroup'])->name('fetch_doctors_by_group');
        Route::post('/fetch-locations-by-doctor', [DashboardController::class, 'fetchLocationsByDoctor'])->name('fetch_locations_by_doctor');
        Route::post('/fetch-mrn-numbers-by-location', [DashboardController::class, 'fetchMrnNumbersByLocation'])->name('fetch_mrn_numbers_by_location');

        //Users Routes
        Route::group(['prefix' => '/users'], function () {
            Route::get('/', [UserController::class, 'index'])->name('admin.users.list');
            Route::get('/create', [UserController::class, 'create'])->name('admin.users.create');
            Route::post('/store', [UserController::class, 'store'])->name('admin.users.store');
            Route::get('/edit/{id}', [UserController::class, 'edit'])->name('admin.users.edit');
            Route::post('/update/{id}', [UserController::class, 'update'])->name('admin.users.update');
            Route::post('/delete', [UserController::class, 'destroy'])->name('admin.users.destroy');
            Route::get('/sync', [UserController::class, 'sync'])->name('admin.users.sync');

            Route::post('/delete-multiple-users', [UserController::class, 'deleteMultipleUsers'])->name('delete_multiple_users');
            Route::get('/trashed', [UserController::class, 'trashed'])->name('admin.users.trashed');
            Route::get('/restore/{id}', [UserController::class, 'restore'])->name('admin.users.restore');
        });
        
        //Groups Routes
        Route::group(['prefix' => '/groups'], function () {
            Route::get('/', [UserGroupController::class, 'index'])->name('admin.groups.list');
            Route::get('/create', [UserGroupController::class, 'create'])->name('admin.groups.create');
            Route::post('/store', [UserGroupController::class, 'store'])->name('admin.groups.store');
            Route::get('/edit/{id}', [UserGroupController::class, 'edit'])->name('admin.groups.edit');
            Route::post('/update/{id}', [UserGroupController::class, 'update'])->name('admin.groups.update');
        });
        
        //Billings Routes
        Route::group(['prefix' => '/billings'], function () {
            Route::get('/', [BillingController::class, 'index'])->name('admin.billings.list');
            Route::post('/get-data', [BillingController::class, 'getData'])->name('admin.billings.get_data');
            Route::get('/create', [BillingController::class, 'create'])->name('admin.billings.create');
            Route::post('/import', [BillingController::class, 'store'])->name('admin.billings.import');
            Route::post('/store', [BillingController::class, 'store'])->name('admin.billings.store');
            Route::post('/export', [BillingController::class, 'export'])->name('admin.billings.export');
            Route::get('/edit/{id}', [BillingController::class, 'edit'])->name('admin.billings.edit');
            Route::post('/update/{id}', [BillingController::class, 'update'])->name('admin.billings.update');
            Route::post('/update-bill-field', [BillingController::class, 'updateBillField'])->name('admin.billings.update_bill_status');
        });
        
        //Files Routes
        Route::group(['prefix' => '/files'], function () {
            Route::get('/', [FileController::class, 'index'])->name('admin.files.list');
        });
        
        //ACL Routes
        Route::group(['prefix' => '/acl'], function () {
            Route::get('/roles/{status?}', [AclController::class, 'index'])->name('admin.acl.roles');
            Route::get('/role/create', [AclController::class, 'create'])->name('admin.acl.role.create');
            Route::post('/role/store', [AclController::class, 'store'])->name('admin.acl.role.store');
            Route::get('/role/{id}/edit', [AclController::class, 'edit'])->name('admin.acl.role.edit');
            Route::post('/role/update/{id}', [AclController::class, 'update'])->name('admin.acl.role.update');
        });
    });
    
    //Doctor Routes
    Route::group(['prefix' => 'doctor'], function () {
        Route::get('/dashboard', [DashboardController::class, 'index'])->name('doctor.dashboard');
        Route::get('/list', [UserController::class, 'users'])->name('doctor.list');
        Route::get('/create', [UserController::class, 'create'])->name('doctor.create');
        Route::post('/store', [UserController::class,'store'])->name('doctor.store');
        Route::get('/edit/{id}', [UserController::class, 'edit'])->name('doctor.edit');
        Route::post('/update/{id}', [UserController::class, 'update'])->name('doctor.update');
    });
    
    //User Routes
    Route::group(['prefix' => 'user'], function () {
        Route::get('/dashboard', [DashboardController::class, 'index'])->name('user.dashboard');
        Route::get('/list', [UserController::class, 'users'])->name('user.list');
        Route::get('/create', [UserController::class, 'create'])->name('user.create');
        Route::post('/store', [UserController::class,'store'])->name('user.store');
        Route::get('/edit/{id}', [UserController::class, 'edit'])->name('user.edit');
        Route::post('/update/{id}', [UserController::class, 'update'])->name('user.update');
    });
});